HTTP request paginator, supporting lazy traversal across large sets
Structs
- Http
Paginator - Call a function with an update
HttpPaginationOptionsfor each batch request, simplifying lazy access to large response sets such as messages etc.