HTTP interface related request/response types.
Structs
- Http
Modem Battery Level Response - Battery status information from the modem.
- Http
Modem Network Operator Response - Network operator information from the modem.
- Http
Modem Network Status Response - Network registration status of the modem.
- Http
Modem Signal Strength Response - Signal strength information from the modem.
- Http
Outgoing SmsMessage - The outgoing SMS message to be sent to a target number.
- Http
Pagination Options - HTTP pagination options allow for lazy reading of large sets of data, for example if thousands of messages have been sent and received from a phone number it would be impractical to request all of them at the same time, instead it can be read in shorter pages using limit+offset. This is applied at the server level when requesting data from database.
- Http
SmsDelivery Report - Delivery report for an already sent SMS message.
- Http
SmsDevice Info Data - Formatted device info response, with each value packed into a proper optional response.
- Http
SmsDevice Info Response - The raw
DeviceInfoResponsewith raw values. - Http
SmsSend Response - Response returned after sending an SMS message.
Type Aliases
- Latest
Number Friendly Name Pair - Used in latest-numbers return value, as a number and friendly name.