Module types

Module types 

Generic types that apply to both HTTP and Websocket interfaces.

Structs

GnssPositionReport
Represents a GNSS position report with optional fields for satellite info.
SmsPartialDeliveryReport
A partial message delivery report, as it comes from the modem.
SmsStoredMessage
Represents a stored SMS message from the database.

Enums

GnssFixStatus
GNSS (Global Navigation Satellite System) fix status.
ModemStatusUpdateState
Represents the current status of the modem.
SmsDeliveryReportStatus
https://www.etsi.org/deliver/etsi_ts/123000_123099/123040/16.00.00_60/ts_123040v160000p.pdf#page=71
SmsDeliveryReportStatusGroup
Generalised group for message delivery status.