Module http

Module http 

SMS-API HTTP client. This can be used to interface with the HTTP API standalone if required.

Modules

error
HTTP interface related errors.
paginator
HTTP request paginator, supporting lazy traversal across large sets

Structs

HttpClient
SMS-API HTTP interface client.