Generic types that apply to both HTTP and Websocket interfaces.
Structs
- Gnss
Position Report - Represents a GNSS position report with optional fields for satellite info.
- SmsPartial
Delivery Report - A partial message delivery report, as it comes from the modem.
- SmsStored
Message - Represents a stored SMS message from the database.
Enums
- Gnss
FixStatus - GNSS (Global Navigation Satellite System) fix status.
- Modem
Status Update State - Represents the current status of the modem.
- SmsDelivery
Report Status - https://www.etsi.org/deliver/etsi_ts/123000_123099/123040/16.00.00_60/ts_123040v160000p.pdf#page=71
- SmsDelivery
Report Status Group - Generalised group for message delivery status.